import fnmatch
import pathlib
import os

_CURRENT_SOURCE_PATH = pathlib.Path(__file__).parent.resolve()
parent_dir = _CURRENT_SOURCE_PATH.parent.resolve()
LIBZENROOM_LOC = os.path.join(parent_dir, fnmatch.filter(
                    os.listdir(parent_dir), "*zenroom*.so")[0])



import matplotlib.pyplot as plt
import pandas as pd

"""
Once obtained the results from:
./benchmark_sig.sh ecdh
./benchmark_sig.qp qp
you can plot the results of time and memory consumed by launching this simple program
"""

def from_csv_to_plot(algos, index, column_to_plot):
    name = ''
    for algo in algos:
        name += (algo+'_')
        df = pd.read_csv(algo+'_sigver.csv')
        
        x = df[index]
        y = df[column_to_plot]
        plt.plot(x, y, '-o', label = algo+'_'+column_to_plot)

    name += column_to_plot

    # to create the image full screen
    figure = plt.gcf()
    figure.set_size_inches(16,9)

    plt.xlabel('message length in B')
    if 'mem' in column_to_plot:
        plt.ylabel('memory used in KiB')
    elif 'time' in column_to_plot:
        plt.ylabel('time consumed in μs')
    plt.legend()
    plt.savefig(name+'.png')
    plt.close()

def main():
    algos = ['qp', 'ecdh']
    index = 'sizes'
    columns_to_plot = ['sig_time', 'sig_mem', 'ver_time', 'ver_mem']
    for column_to_plot in columns_to_plot:
        from_csv_to_plot(algos, index, column_to_plot)


if __name__=="__main__":
    main()



import pytest
from schema import Schema, Regex
from zenroom import zenroom_exec, zencode_exec


def test_zencode_call_random_array():
    contract =  """Given nothing
When I create the array of '64' random numbers modulo '100'
and I create the aggregation of array 'array'
Then print the 'array' as 'number'
and print the 'aggregation' as 'number'
"""
    res = zencode_exec(
        contract
    )
    out_regex = r'{\"aggregation\":\d{4},\"array\":\[(?:\d{1,3}\,)+\d{1,3}\]}'
    assert Regex(out_regex).validate(res.output)
    assert Schema({
        'aggregation': int,
        'array': [int]
    }).validate(res.result)

def test_zencode_failure():
    contract = """
Given I have a 'string' named 'string'
Then print the data
"""
    res = zencode_exec(contract)
    assert("ERROR" in res.logs)

def test_lua_call_hello_world():
    lua_res = zenroom_exec(
        "print('hello world')"
    )
    assert lua_res.output == 'hello world'



import sys
from pathlib import Path
from time import process_time

path = Path("../bindings/python3/zenroom/")
sys.path.append(path.resolve())

from zenroom.zenroom import zenroom_exec

print("[PY] zenroom_exec %s" % sys.argv[1])
script_path = Path(sys.argv[1])

try:
    script = script_path.read_text()
except UnicodeDecodeError:
    script = script_path.read_text(encoding='iso-8859-1')

start = process_time()
result = zenroom_exec(script=script)
end = process_time() - start

print(result if result else '')
print("--- %s seconds ---" % end)
print("@", "="*40, "@")
